"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineDevSettings = void 0;
const fs_extra_1 = require("fs-extra");
const content_types_1 = require("@ewizardjs/content-types");
const builder_utils_1 = require("@ewizardjs/builder-utils");
const path_1 = require("path");
const ramda_1 = require("ramda");
const plugins_1 = require("@ewizardjs/builder-utils/plugins");
async function defineDevSettings(options, systemSettings) {
    const presentationPath = options.presentationPath;
    const blocksDir = ramda_1.pathOr('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = ramda_1.pathOr('', ['path', 'localBlocks'], systemSettings);
    const componentsManifestFilePath = ramda_1.pathOr('', ['path', 'componentsManifest'], systemSettings);
    const componentsManifestFileName = ramda_1.pathOr('', ['path', 'componentsFilename'], systemSettings);
    const blocksManifestFileName = ramda_1.pathOr('', ['path', 'blocksManifest'], systemSettings);
    const modulesManifestFileName = ramda_1.pathOr('', ['path', 'modulesManifest'], systemSettings);
    const blocksThemesFileName = ramda_1.pathOr('', ['path', 'blocksThemes'], systemSettings);
    const componentsThemesFileName = ramda_1.pathOr('', ['path', 'componentsThemes'], systemSettings);
    const componentsDir = ramda_1.pathOr('', ['path', 'localComponents'], systemSettings);
    const slidesDir = ramda_1.pathOr('', ['path', 'slides'], systemSettings);
    const { fileProps } = await builder_utils_1.getComponentsFileProps(presentationPath);
    const localBlocksPath = path_1.resolve(presentationPath, localBlocksDir);
    const libraryBlocksPath = path_1.resolve(presentationPath, blocksDir);
    const blocksManifestPath = path_1.resolve(presentationPath, blocksManifestFileName);
    const modulesManifestPath = path_1.resolve(presentationPath, modulesManifestFileName);
    const blocksThemesManifestPath = path_1.resolve(presentationPath, blocksThemesFileName);
    const componentsThemesManifestPath = path_1.resolve(presentationPath, componentsThemesFileName);
    const structureJsonPath = path_1.resolve(presentationPath, 'structure.json');
    const componentsManifestPath = componentsManifestFilePath
        ? path_1.resolve(presentationPath, componentsManifestFilePath)
        : path_1.resolve(presentationPath, componentsDir, componentsManifestFileName);
    const [componentsManifestExists, blocksManifestExists, modulesManifestExists, blocksThemesManifestExists, componentsThemesManifestExists,] = await Promise.all([
        fs_extra_1.pathExists(componentsManifestPath),
        fs_extra_1.pathExists(blocksManifestPath),
        fs_extra_1.pathExists(modulesManifestPath),
        fs_extra_1.pathExists(blocksThemesManifestPath),
        fs_extra_1.pathExists(componentsThemesManifestPath),
    ]);
    const pluginContentTypes = Object.keys(content_types_1.ContentTypes).reduce((obj, key) => (Object.assign(Object.assign({}, obj), { [key]: JSON.stringify(content_types_1.ContentTypes[key]) })), {});
    const structureJson = await getStructureJSON(structureJsonPath);
    logNewestStructureWarning(structureJson);
    const plugin = plugins_1.defineSettings(presentationPath, systemSettings, 'dev', false, structureJson === null || structureJson === void 0 ? void 0 : structureJson.structureFileVersion);
    plugin.definitions['process.env'] = Object.assign(Object.assign({}, plugin.definitions['process.env']), { LOCAL_BLOCKS: JSON.stringify(localBlocksPath), LIBRARY_BLOCKS: JSON.stringify(libraryBlocksPath), COMPONENTS_MANIFEST: JSON.stringify(componentsManifestExists ? componentsManifestPath : ''), BLOCKS_MANIFEST: JSON.stringify(blocksManifestExists ? blocksManifestPath : ''), BLOCKS_THEMES_MANIFEST: JSON.stringify(blocksThemesManifestExists ? blocksThemesManifestPath : ''), COMPONENTS_THEMES_MANIFEST: JSON.stringify(componentsThemesManifestExists ? componentsThemesManifestPath : ''), MODULES_MANIFEST: JSON.stringify(modulesManifestExists ? modulesManifestPath : ''), SLIDES_DIR: JSON.stringify(path_1.resolve(presentationPath, slidesDir)), COMPONENT_FILE_PROPS: JSON.stringify(fileProps) });
    plugin.definitions.ContentTypes = pluginContentTypes;
    return plugin;
}
exports.defineDevSettings = defineDevSettings;
async function getStructureJSON(structureJsonPath) {
    try {
        return await fs_extra_1.readJSON(structureJsonPath);
    }
    catch (error) { }
}
const logNewestStructureWarning = (() => {
    let wasCalled = false;
    return (structureJson) => {
        if (wasCalled) {
            return;
        }
        wasCalled = true;
        if ((structureJson === null || structureJson === void 0 ? void 0 : structureJson.structureFileVersion) === 2) {
            console.warn('You\'re using structure 2 (Beta) supported in dev builds only. Consider not using it in prod builds and eWizard Editor');
        }
    };
})();
//# sourceMappingURL=defineDevSettings.js.map